# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateMtaStsRecordResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'type': 'str',
        'ttl': 'int',
        'value': 'str',
        'well_known_value': 'str',
        'well_known_url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'ttl': 'ttl',
        'value': 'value',
        'well_known_value': 'wellKnownValue',
        'well_known_url': 'wellKnownUrl'
    }

    def __init__(self, name=None, type=None, ttl=None, value=None, well_known_value=None, well_known_url=None, local_vars_configuration=None):  # noqa: E501
        """GenerateMtaStsRecordResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._type = None
        self._ttl = None
        self._value = None
        self._well_known_value = None
        self._well_known_url = None
        self.discriminator = None

        self.name = name
        self.type = type
        self.ttl = ttl
        self.value = value
        self.well_known_value = well_known_value
        self.well_known_url = well_known_url

    @property
    def name(self):
        """Gets the name of this GenerateMtaStsRecordResults.  # noqa: E501


        :return: The name of this GenerateMtaStsRecordResults.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GenerateMtaStsRecordResults.


        :param name: The name of this GenerateMtaStsRecordResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this GenerateMtaStsRecordResults.  # noqa: E501

        Domain Name Server Record Types  # noqa: E501

        :return: The type of this GenerateMtaStsRecordResults.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GenerateMtaStsRecordResults.

        Domain Name Server Record Types  # noqa: E501

        :param type: The type of this GenerateMtaStsRecordResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["A", "NS", "MD", "MF", "CNAME", "SOA", "MB", "MG", "MR", "NULL", "WKS", "PTR", "HINFO", "MINFO", "MX", "TXT", "RP", "AFSDB", "X25", "ISDN", "RT", "NSAP", "NSAP_PTR", "SIG", "KEY", "PX", "GPOS", "AAAA", "LOC", "NXT", "EID", "NIMLOC", "SRV", "ATMA", "NAPTR", "KX", "CERT", "A6", "DNAME", "SINK", "OPT", "APL", "DS", "SSHFP", "IPSECKEY", "RRSIG", "NSEC", "DNSKEY", "DHCID", "NSEC3", "NSEC3PARAM", "TLSA", "SMIMEA", "HIP", "NINFO", "RKEY", "TALINK", "CDS", "CDNSKEY", "OPENPGPKEY", "CSYNC", "ZONEMD", "SVCB", "HTTPS", "SPF", "UINFO", "UID", "GID", "UNSPEC", "NID", "L32", "L64", "LP", "EUI48", "EUI64", "TKEY", "TSIG", "IXFR", "AXFR", "MAILB", "MAILA", "ANY", "URI", "CAA", "AVC", "DOA", "AMTRELAY", "TA", "DLV"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def ttl(self):
        """Gets the ttl of this GenerateMtaStsRecordResults.  # noqa: E501


        :return: The ttl of this GenerateMtaStsRecordResults.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this GenerateMtaStsRecordResults.


        :param ttl: The ttl of this GenerateMtaStsRecordResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and ttl is None:  # noqa: E501
            raise ValueError("Invalid value for `ttl`, must not be `None`")  # noqa: E501

        self._ttl = ttl

    @property
    def value(self):
        """Gets the value of this GenerateMtaStsRecordResults.  # noqa: E501


        :return: The value of this GenerateMtaStsRecordResults.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this GenerateMtaStsRecordResults.


        :param value: The value of this GenerateMtaStsRecordResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def well_known_value(self):
        """Gets the well_known_value of this GenerateMtaStsRecordResults.  # noqa: E501


        :return: The well_known_value of this GenerateMtaStsRecordResults.  # noqa: E501
        :rtype: str
        """
        return self._well_known_value

    @well_known_value.setter
    def well_known_value(self, well_known_value):
        """Sets the well_known_value of this GenerateMtaStsRecordResults.


        :param well_known_value: The well_known_value of this GenerateMtaStsRecordResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and well_known_value is None:  # noqa: E501
            raise ValueError("Invalid value for `well_known_value`, must not be `None`")  # noqa: E501

        self._well_known_value = well_known_value

    @property
    def well_known_url(self):
        """Gets the well_known_url of this GenerateMtaStsRecordResults.  # noqa: E501


        :return: The well_known_url of this GenerateMtaStsRecordResults.  # noqa: E501
        :rtype: str
        """
        return self._well_known_url

    @well_known_url.setter
    def well_known_url(self, well_known_url):
        """Sets the well_known_url of this GenerateMtaStsRecordResults.


        :param well_known_url: The well_known_url of this GenerateMtaStsRecordResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and well_known_url is None:  # noqa: E501
            raise ValueError("Invalid value for `well_known_url`, must not be `None`")  # noqa: E501

        self._well_known_url = well_known_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateMtaStsRecordResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateMtaStsRecordResults):
            return True

        return self.to_dict() != other.to_dict()
